==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/SciFigs/src/ExternalPlotLine2D.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  SciFigs is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  SciFigs is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-02-17
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef EXTERNALPLOTLINE2D_H
#define EXTERNALPLOTLINE2D_H

#include "AbstractLine.h"
#include "SciFigsDLLExport.h"

namespace SciFigs {

  class SCIFIGS_EXPORT ExternalPlotLine2D : public AbstractLine
  {
    TRANSLATIONS("ExternalPlotLine2D")
  public:
    virtual AbstractLine * clone() const;
    virtual void operator=(const ExternalPlotLine2D& o);

    virtual int count() const {return _curve->count();}
    virtual void clear() {_curve->clear();}
    virtual void append() {_curve->append(Point2D());}
    virtual void insert(int index) {_curve->insert(index, Point2D());}
    virtual void removeLast() {_curve->remove(_curve->count()-1);}
    virtual bool isSorted() const {return _curve->isSorted();}
    virtual void checkSort() {_curve->checkSort();}
    virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
      _curve->indexRange(xMin, xMax, indexMin, indexMax);
    }
    virtual Point point(int index, const CurvePointOptions *) const {return _curve->at(index);}
    virtual void setX(int index, double v) {(*_curve)[index].setX(v);}
    virtual void setY(int index, double v, const CurvePointOptions *) {(*_curve)[index].setY(v);}
    virtual void setZ(int, double, const CurvePointOptions *) {}

    const Curve<Point2D> * curve() const {return _curve;}
    Curve<Point2D> * curve() {return _curve;}
    void setCurve(Curve<Point2D> * curve);
    void setCurve(Curve<Point2D> * curve, const Pen& pen, const Symbol& sym);
  protected:
    Curve<Point2D> * _curve;
  };

} // namespace SciFigs

#endif // EXTERNALPLOTLINE2D_H

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/SciFigs/src/ExternalPlotLine2D.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  SciFigs is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  SciFigs is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-02-17
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef EXTERNALPLOTLINE2D_H
#define EXTERNALPLOTLINE2D_H

#include "AbstractLine.h"
#include "SciFigsDLLExport.h"

namespace SciFigs {

  class SCIFIGS_EXPORT ExternalPlotLine2D : public AbstractLine
  {
    TRANSLATIONS("ExternalPlotLine2D")
  public:
    virtual AbstractLine * clone() const;
    virtual void operator=(const ExternalPlotLine2D& o);

    virtual int count() const {return _curve->count();}
    virtual void clear() {_curve->clear();}
    virtual void append() {_curve->append(Point2D());}
    virtual void insert(int index) {_curve->insert(index, Point2D());}
    virtual void removeLast() {_curve->remove(_curve->count()-1);}
    virtual bool isSorted() const {return _curve->isSorted();}
    virtual void checkSort() {_curve->checkSort();}
    virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
      _curve->indexRange(xMin, xMax, indexMin, indexMax);
    }
    virtual Point point(int index, const CurvePointOptions *) const {return _curve->constAt(index);}
    virtual void setX(int index, double v) {_curve->setX(index, v);}
    virtual void setY(int index, double v, const CurvePointOptions *) {_curve->setY(index, v);}
    virtual void setZ(int, double, const CurvePointOptions *) {}

    const Curve<Point2D> * curve() const {return _curve;}
    Curve<Point2D> * curve() {return _curve;}
    void setCurve(Curve<Point2D> * curve);
    void setCurve(Curve<Point2D> * curve, const Pen& pen, const Symbol& sym);
  protected:
    Curve<Point2D> * _curve;
  };

} // namespace SciFigs

#endif // EXTERNALPLOTLINE2D_H
